Coverage for markupmirror.markup.html: 100%

# Coverage for markupmirror.markup.html : 100%

## 8 statements 8 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 | from django.utils.translation import ugettext_lazy as _ from markupmirror.markup.base import BaseMarkup from markupmirror.markup.base import register_markup class HtmlMarkup(BaseMarkup): """Markup pseudo-transformer for HTML content. This does not transform anything and thus is potentially harmful. Use with care. """ codemirror_mode = 'text/html' title = _(u"HTML") register_markup(HtmlMarkup) __all__ = ('HtmlMarkup',)